==> senior_design_system-0.17.0.tar.gz: lib/components/senior_badge/senior_badge_widget.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

/// Possible shapes for [SeniorBadge].
enum SeniorBadgeShape { pill, chip }

class SeniorBadge extends StatelessWidget {
  /// Creates a badge component.
  /// 
  /// [backgroundColor], [fontColor] and [label] parameters need to be provided.
  /// If [disabledBackgroundColor] and [disabledFontColor] parameters are not 
  /// specified, the values of [backgroundColor] and [fontColor] parameters 
  /// respectively will be used.
  const SeniorBadge({
    Key? key,
    required this.backgroundColor,
    this.disabled = false,
    this.disabledBackgroundColor,
    this.disabledFontColor,
    required this.fontColor,
    required this.label,
    this.shape = SeniorBadgeShape.chip,
  }) : super(key: key);

  /// Creates a variation of [SeniorBadge] with an icon preceding the badge 
  /// text.
  /// 
  /// The [icon] parameter is required.
  factory SeniorBadge.icon({
    Key? key,
    required Color backgroundColor,
    bool disabled,
    Color? disabledBackgroundColor,
    Color? disabledFontColor,
    required Color fontColor,
    required IconData icon,
    required String label,
    SeniorBadgeShape shape,
  }) = _SeniorBadgeIcon;

  /// The background color of the badge.
  final Color backgroundColor;

  /// The background color displayed when the badge is disabled.
  /// 
  /// If this parameter is not specified, the value of [backgroundColor] will 
  /// be used.
  final Color? disabledBackgroundColor;

  /// The font color of the badge.
  final Color fontColor;

  /// The font color displayed when the badge is disabled.
  /// 
  /// If this parameter is not specified, the value of [fontColor] will be used.
  final Color? disabledFontColor;

  /// The badge text. 
  final String label;

  /// Whether the badge will be disabled or not.
  /// 
  /// By default it is false, enabled.
  final bool disabled;

  /// The shape of the badge.
  /// 
  /// Possible values are [SeniorBadgeShape.chip] and [SeniorBadgeShape.pill].
  final SeniorBadgeShape shape;

  Color _getBackgroundColor() {
    if (disabledBackgroundColor == null) {
      return backgroundColor;
    }
    return disabled ? disabledBackgroundColor! : backgroundColor;
  }

  Color _getFontColor() {
    if (disabledFontColor == null) {
      return fontColor;
    }
    return disabled ? disabledFontColor! : fontColor;
  }

  double _getShapeRadius() {
    switch (shape) {
      case SeniorBadgeShape.pill:
        return SeniorRadius.huge;
      case SeniorBadgeShape.chip:
      default:
        return SeniorRadius.medium;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.symmetric(
        horizontal: SeniorSpacing.normal,
        vertical: SeniorSpacing.xxsmall,
      ),
      decoration: BoxDecoration(
        color: _getBackgroundColor(),
        borderRadius: BorderRadius.all(
          Radius.circular(_getShapeRadius()),
        ),
      ),
      child: Text(
        label,
        style: SeniorTypography.small(
          color: _getFontColor(),
        ),
      ),
    );
  }
}

class _SeniorBadgeIcon extends SeniorBadge {
  const _SeniorBadgeIcon({
    Key? key,
    required Color backgroundColor,
    bool disabled = false,
    Color? disabledBackgroundColor,
    Color? disabledFontColor,
    required Color fontColor,
    required this.icon,
    required String label,
    SeniorBadgeShape shape = SeniorBadgeShape.pill,
  }) : super(
          key: key,
          backgroundColor: backgroundColor,
          disabled: disabled,
          disabledBackgroundColor: disabledBackgroundColor,
          disabledFontColor: disabledFontColor,
          fontColor: fontColor,
          label: label,
          shape: shape,
        );

  /// The Badge Icon.
  final IconData icon;

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.symmetric(
        vertical: SeniorSpacing.xxsmall,
        horizontal: SeniorSpacing.small,
      ),
      decoration: BoxDecoration(
        color: _getBackgroundColor(),
        borderRadius: BorderRadius.all(
          Radius.circular(_getShapeRadius()),
        ),
      ),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Padding(
            padding: const EdgeInsets.only(
              right: SeniorSpacing.xsmall,
            ),
            child: FaIcon(
              icon,
              color: _getFontColor(),
              size: SeniorTypographyIconSize.text,
            ),
          ),
          Text(
            label,
            style: SeniorTypography.title(
              color: _getFontColor(),
            ),
          ),
        ],
      ),
    );
  }
}

==> senior_design_system-2.1.3.tar.gz: lib/components/senior_badge/senior_badge_widget.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

/// Possible shapes for [SeniorBadge].
enum SeniorBadgeShape { pill, chip }

class SeniorBadge extends StatelessWidget {
  /// Creates a badge component.
  ///
  /// [backgroundColor], [fontColor] and [label] parameters need to be provided.
  /// If [disabledBackgroundColor] and [disabledFontColor] parameters are not
  /// specified, the values of [backgroundColor] and [fontColor] parameters
  /// respectively will be used.
  const SeniorBadge({
    Key? key,
    required this.backgroundColor,
    this.disabled = false,
    this.disabledBackgroundColor,
    this.disabledFontColor,
    required this.fontColor,
    required this.label,
    this.shape = SeniorBadgeShape.chip,
  }) : super(key: key);

  /// Creates a variation of [SeniorBadge] with an icon preceding the badge
  /// text.
  ///
  /// The [icon] parameter is required.
  factory SeniorBadge.icon({
    Key? key,
    required Color backgroundColor,
    bool disabled,
    Color? disabledBackgroundColor,
    Color? disabledFontColor,
    required Color fontColor,
    required IconData icon,
    required String label,
    SeniorBadgeShape shape,
  }) = _SeniorBadgeIcon;

  /// The background color of the badge.
  final Color backgroundColor;

  /// The background color displayed when the badge is disabled.
  ///
  /// If this parameter is not specified, the value of [backgroundColor] will
  /// be used.
  final Color? disabledBackgroundColor;

  /// The font color of the badge.
  final Color fontColor;

  /// The font color displayed when the badge is disabled.
  ///
  /// If this parameter is not specified, the value of [fontColor] will be used.
  final Color? disabledFontColor;

  /// The badge text.
  final String label;

  /// Whether the badge will be disabled or not.
  ///
  /// By default it is false, enabled.
  final bool disabled;

  /// The shape of the badge.
  ///
  /// Possible values are [SeniorBadgeShape.chip] and [SeniorBadgeShape.pill].
  final SeniorBadgeShape shape;

  Color _getBackgroundColor() {
    if (disabledBackgroundColor == null) {
      return backgroundColor;
    }
    return disabled ? disabledBackgroundColor! : backgroundColor;
  }

  Color _getFontColor() {
    if (disabledFontColor == null) {
      return fontColor;
    }
    return disabled ? disabledFontColor! : fontColor;
  }

  double _getShapeRadius() {
    switch (shape) {
      case SeniorBadgeShape.pill:
        return SeniorRadius.huge;
      case SeniorBadgeShape.chip:
      default:
        return SeniorRadius.medium;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.symmetric(
        horizontal: SeniorSpacing.normal,
        vertical: SeniorSpacing.xxsmall,
      ),
      decoration: BoxDecoration(
        color: _getBackgroundColor(),
        borderRadius: BorderRadius.all(
          Radius.circular(_getShapeRadius()),
        ),
      ),
      child: Text(
        label,
        style: SeniorTypography.small(
          color: _getFontColor(),
        ),
      ),
    );
  }
}

class _SeniorBadgeIcon extends SeniorBadge {
  const _SeniorBadgeIcon({
    Key? key,
    required Color backgroundColor,
    bool disabled = false,
    Color? disabledBackgroundColor,
    Color? disabledFontColor,
    required Color fontColor,
    required this.icon,
    required String label,
    SeniorBadgeShape shape = SeniorBadgeShape.pill,
  }) : super(
          key: key,
          backgroundColor: backgroundColor,
          disabled: disabled,
          disabledBackgroundColor: disabledBackgroundColor,
          disabledFontColor: disabledFontColor,
          fontColor: fontColor,
          label: label,
          shape: shape,
        );

  /// The Badge Icon.
  final IconData icon;

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.symmetric(
        vertical: SeniorSpacing.xxsmall,
        horizontal: SeniorSpacing.small,
      ),
      decoration: BoxDecoration(
        color: _getBackgroundColor(),
        borderRadius: BorderRadius.all(
          Radius.circular(_getShapeRadius()),
        ),
      ),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Padding(
            padding: const EdgeInsets.only(
              right: SeniorSpacing.xsmall,
            ),
            child: Icon(
              icon,
              color: _getFontColor(),
              size: 14.0,
            ),
          ),
          Text(
            label,
            style: SeniorTypography.small(
              color: _getFontColor(),
            ),
          ),
        ],
      ),
    );
  }
}
